@@ -20,14 +20,14 @@
 #ifndef PROFILES_H_
 #define PROFILES_H_
 
-#define CLICK_DELAY 20
-
 /* Blacklist */
-char* blacklist[] = { "xournal", "gimp-2.6", "mypaint", "inkscape" };
-int blacklistLength = 4;
+char* blacklist[] = { "xournal", "gimp-2.6", "gimp", "mypaint", "inkscape", NULL };
+
+/* WM-Blacklist */
+char* wmBlacklist[] = { "kwin", "mutter", NULL };
 
 /* Profiles */
-int profileCount = 7;
+int profileCount = 8;
 Profile profiles[] = {
 				{ 	.windowClass = "evince",
 					.scrollInherit = 0,
@@ -39,6 +39,7 @@ Profile profiles[] = {
 					.scrollDownAction = { ACTIONTYPE_NONE,0,0 },
 					.scrollLeftAction = { ACTIONTYPE_NONE,0,0 },
 					.scrollRightAction = { ACTIONTYPE_NONE,0,0 },
+					.scrollEasing = 0,
 					.zoomInherit = 0,
 					.zoomMinDistance = 80,
 					.zoomInAction = { ACTIONTYPE_BUTTONPRESS, 4, MODIFIER_CONTROL },
@@ -62,6 +63,7 @@ Profile profiles[] = {
 					.scrollDownAction = { ACTIONTYPE_NONE,0,0 },
 					.scrollLeftAction = { ACTIONTYPE_NONE,0,0 },
 					.scrollRightAction = { ACTIONTYPE_NONE,0,0 },
+					.scrollEasing = 0,
 					.zoomInherit = 0,
 					.zoomMinDistance = 80,
 					.zoomInAction = { ACTIONTYPE_BUTTONPRESS, 4, 0 },
@@ -87,6 +89,7 @@ Profile profiles[] = {
 					.scrollDownAction = { ACTIONTYPE_BUTTONPRESS, 4, MODIFIER_SHIFT },
 					.scrollLeftAction = { ACTIONTYPE_BUTTONPRESS, 7, MODIFIER_SHIFT },
 					.scrollRightAction = { ACTIONTYPE_BUTTONPRESS, 6, MODIFIER_SHIFT },
+					.scrollEasing = 1,
 					.zoomInherit = 0,
 					.zoomMinDistance = 80,
 					.zoomInAction = { ACTIONTYPE_BUTTONPRESS, 4, 0 },
@@ -110,6 +113,7 @@ Profile profiles[] = {
 					.scrollDownAction = { ACTIONTYPE_BUTTONPRESS,4,0 },
 					.scrollLeftAction = { ACTIONTYPE_KEYPRESS,XK_Right, MODIFIER_CONTROL | MODIFIER_ALT },
 					.scrollRightAction = { ACTIONTYPE_KEYPRESS,XK_Left, MODIFIER_CONTROL | MODIFIER_ALT },
+					.scrollEasing = 0,
 					.zoomInherit = 1,
 					.rotateInherit = 1,
 					.tapInherit = 1
@@ -124,6 +128,7 @@ Profile profiles[] = {
 					.scrollDownAction = { ACTIONTYPE_BUTTONPRESS,4,0 },
 					.scrollLeftAction = { ACTIONTYPE_KEYPRESS,XK_Right, MODIFIER_CONTROL | MODIFIER_ALT },
 					.scrollRightAction = { ACTIONTYPE_KEYPRESS,XK_Left, MODIFIER_CONTROL | MODIFIER_ALT },
+					.scrollEasing = 0,
 					.zoomInherit = 1,
 					.rotateInherit = 1,
 					.tapInherit = 1
@@ -138,6 +143,7 @@ Profile profiles[] = {
 					.scrollDownAction = { ACTIONTYPE_BUTTONPRESS, 4, 0 },
 					.scrollLeftAction = { ACTIONTYPE_BUTTONPRESS, 5, MODIFIER_SHIFT },
 					.scrollRightAction = { ACTIONTYPE_BUTTONPRESS, 4, MODIFIER_SHIFT },
+					.scrollEasing = 1,
 					.zoomInherit = 0,
 					.zoomMinDistance = 80,
 					.zoomInAction = { ACTIONTYPE_KEYPRESS, XK_equal, MODIFIER_CONTROL },
@@ -152,60 +158,88 @@ Profile profiles[] = {
 					.tapInherit = 1
 				},
 			 	{	.windowClass = "SimCity 4.exe",
-								.scrollInherit = 0,
-								.scrollMinDistance = 20,
-								.hscrollStep = 1000,
-								.vscrollStep = 1000,
-								.scrollBraceAction = { ACTIONTYPE_BUTTONPRESS, 3, 0	},
-								.scrollUpAction = { ACTIONTYPE_NONE,0,0 },
-								.scrollDownAction = { ACTIONTYPE_NONE,0,0 },
-								.scrollLeftAction = { ACTIONTYPE_NONE,0,0 },
-								.scrollRightAction = { ACTIONTYPE_NONE,0,0 },
-//								.scrollMinDistance = 20,
-//								.hscrollStep = 10,
-//								.vscrollStep = 10,
-//								.scrollBraceAction = { ACTIONTYPE_NONE,0,0 },
-//								.scrollUpAction = { ACTIONTYPE_KEYPRESS, XK_Down, 0 },
-//								.scrollDownAction = { ACTIONTYPE_KEYPRESS, XK_Up, 0 },
-//								.scrollLeftAction = { ACTIONTYPE_KEYPRESS, XK_Right, 0 },
-//								.scrollRightAction = { ACTIONTYPE_KEYPRESS, XK_Left, 0 },
-								.zoomInherit = 0,
-								.zoomMinDistance = 80,
-								.zoomInAction = { ACTIONTYPE_BUTTONPRESS, 4, 0 },
-								.zoomOutAction = { ACTIONTYPE_BUTTONPRESS, 5, 0 },
-								.zoomStep = 1.5,
-								.rotateInherit = 1,
-								.tapInherit = 1
-							}
+					.scrollInherit = 0,
+					.scrollMinDistance = 20,
+					.hscrollStep = 1000,
+					.vscrollStep = 1000,
+					.scrollBraceAction = { ACTIONTYPE_BUTTONPRESS, 3, 0	},
+					.scrollUpAction = { ACTIONTYPE_NONE,0,0 },
+					.scrollDownAction = { ACTIONTYPE_NONE,0,0 },
+					.scrollLeftAction = { ACTIONTYPE_NONE,0,0 },
+					.scrollRightAction = { ACTIONTYPE_NONE,0,0 },
+					.scrollEasing = 0,
+//					.scrollMinDistance = 20,
+//					.hscrollStep = 10,
+//					.vscrollStep = 10,
+//					.scrollBraceAction = { ACTIONTYPE_NONE,0,0 },
+//					.scrollUpAction = { ACTIONTYPE_KEYPRESS, XK_Down, 0 },
+//					.scrollDownAction = { ACTIONTYPE_KEYPRESS, XK_Up, 0 },
+//					.scrollLeftAction = { ACTIONTYPE_KEYPRESS, XK_Right, 0 },
+//					.scrollRightAction = { ACTIONTYPE_KEYPRESS, XK_Left, 0 },
+					.zoomInherit = 0,
+					.zoomMinDistance = 80,
+					.zoomInAction = { ACTIONTYPE_BUTTONPRESS, 4, 0 },
+					.zoomOutAction = { ACTIONTYPE_BUTTONPRESS, 5, 0 },
+					.zoomStep = 1.5,
+					.rotateInherit = 1,
+					.tapInherit = 1
+				},
+				{ 	.windowClass = "googleearth-bin",
+					.scrollInherit = 0,
+					.scrollMinDistance = 100,
+					.hscrollStep = 30,
+					.vscrollStep = 30,
+					.scrollBraceAction = { ACTIONTYPE_KEYPRESS, XK_Shift_L, 0 },
+					.scrollUpAction = { ACTIONTYPE_BUTTONPRESS,4,0 },
+					.scrollDownAction = { ACTIONTYPE_BUTTONPRESS,5,0 },
+					.scrollLeftAction = { ACTIONTYPE_NONE,0,0 },
+					.scrollRightAction = { ACTIONTYPE_NONE,0,0 },
+					.scrollEasing = 0,
+					.zoomInherit = 0,
+					.zoomMinDistance = 80,
+					.zoomInAction = { ACTIONTYPE_BUTTONPRESS, 4, 0 },
+					.zoomOutAction = { ACTIONTYPE_BUTTONPRESS, 5, 0 },
+					.zoomStep = 1.2,
+					.rotateInherit = 0,
+					.rotateMinDistance = 100,
+					.rotateMinAngle = 10,
+					.rotateStep = 15,
+					.rotateLeftAction = { ACTIONTYPE_BUTTONPRESS, 5, MODIFIER_CONTROL },
+					.rotateRightAction = { ACTIONTYPE_BUTTONPRESS, 4, MODIFIER_CONTROL },
+					.tapInherit = 1
+					//,
+					//.tapAction = {ACTIONTYPE_NONE,0,0 }
+				}
 			};
 /* DON'T FORGET TO CHANGE profileCount WHEN ADDING PROFILES! */
 
 
 /* Default (fallback) profile */
 Profile defaultProfile = {	.windowClass = NULL,
-							.scrollInherit = 0,
-							.hscrollStep = 40,
-							.vscrollStep = 40,
-							.scrollMinDistance = 50,
-							.scrollBraceAction = { ACTIONTYPE_NONE,0,0 },
-							.scrollUpAction = { ACTIONTYPE_BUTTONPRESS, 5, 0 },
-							.scrollDownAction = { ACTIONTYPE_BUTTONPRESS, 4, 0 },
-							.scrollLeftAction = { ACTIONTYPE_BUTTONPRESS, 7, 0 },
-							.scrollRightAction = { ACTIONTYPE_BUTTONPRESS, 6, 0 },
-							.zoomInherit = 0,
-							.zoomMinDistance = 100,
-							.zoomInAction = { ACTIONTYPE_BUTTONPRESS, 4, MODIFIER_CONTROL },
-							.zoomOutAction = { ACTIONTYPE_BUTTONPRESS, 5, MODIFIER_CONTROL },
-							.zoomStep = 1.5,
-							.rotateInherit = 0,
-							.rotateMinDistance = 10000,
-							.rotateMinAngle = 370,
-							.rotateLeftAction = { ACTIONTYPE_NONE,0,0 },
-							.rotateRightAction = { ACTIONTYPE_NONE,0,0 },
-							.rotateStep = 90,
-							.tapInherit = 0,
-							.tapAction = { ACTIONTYPE_BUTTONPRESS, 3, 0	}
-						  };
+				.scrollInherit = 0,
+				.hscrollStep = 40,
+				.vscrollStep = 40,
+				.scrollMinDistance = 50,
+				.scrollBraceAction = { ACTIONTYPE_NONE,0,0 },
+				.scrollUpAction = { ACTIONTYPE_BUTTONPRESS, 5, 0 },
+				.scrollDownAction = { ACTIONTYPE_BUTTONPRESS, 4, 0 },
+				.scrollLeftAction = { ACTIONTYPE_BUTTONPRESS, 7, 0 },
+				.scrollRightAction = { ACTIONTYPE_BUTTONPRESS, 6, 0 },
+				.scrollEasing = 1,
+				.zoomInherit = 0,
+				.zoomMinDistance = 80,
+				.zoomInAction = { ACTIONTYPE_BUTTONPRESS, 4, MODIFIER_CONTROL },
+				.zoomOutAction = { ACTIONTYPE_BUTTONPRESS, 5, MODIFIER_CONTROL },
+				.zoomStep = 1.5,
+				.rotateInherit = 0,
+				.rotateMinDistance = 10000,
+				.rotateMinAngle = 370,
+				.rotateLeftAction = { ACTIONTYPE_NONE,0,0 },
+				.rotateRightAction = { ACTIONTYPE_NONE,0,0 },
+				.rotateStep = 90,
+				.tapInherit = 0,
+				.tapAction = { ACTIONTYPE_BUTTONPRESS, 3, 0	}
+			  };
 
 
 #endif /* PROFILES_H_ */
