@@ -54,6 +54,7 @@ struct Profile {
 	int hscrollStep;
 	int vscrollStep;
 	int scrollMinDistance;
+	int scrollEasing;
 
 	int zoomInherit;
 	Action zoomInAction;
@@ -86,26 +87,39 @@ struct Profile {
 #define GESTURE_ZOOM 3
 #define GESTURE_ROTATE 4
 
-int main(int argc,char **argv);
+int inDebugMode();
+
 void *xLoopThreadFunction(void *arg);
 void windowMapped(Window w);
 int isWindowBlacklisted(Window w);
 void enterBlacklistedWindow();
 void leaveWindow();
-void processFingers();
-Profile *getWindowProfile(Window w);
+
 Window getCurrentWindow();
-int checkGesture();
+char* getWindowClass(Window);
+Window getLastChildWindow(Window);
+
+void processFingers();
+
+void pressButton();
 void releaseButton();
+int isButtonDown();
+
+void movePointer(int, int);
+void executeAction(Action* action, int what);
+
 void deactivate();
 void activate();
-void postGesture();
-void preGesture();
-void executeAction(Action* action, int what);
+
 void ungrab(Display *display,int deviceid);
 void grab(Display *display,int deviceid);
-void resetDownValues();
+
 int invalidWindowHandler(Display *dsp,XErrorEvent *err);
+
 void readCalibrationData();
+void startContinuation();
+
+Time getCurrentTime();
+
 
 #endif /* TWOFINGEMU_H_ */
